==> haskell-servant-0.11-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.11
id: servant-0.11-2Bfoi0pupMeH5XDpNx7DXi
key: servant-0.11-2Bfoi0pupMeH5XDpNx7DXi
license: BSD3
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant Web
author: Servant Contributors
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Header
    Servant.API.HttpVersion Servant.API.Internal.Test.ComprehensiveAPI
    Servant.API.IsSecure Servant.API.QueryParam Servant.API.Raw
    Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Sub Servant.API.TypeLevel
    Servant.API.Vault Servant.API.Verbs Servant.API.WithNamedContext
    Servant.Utils.Links Servant.Utils.Enter
abi: f5155ade7127cb84ed39306b7d8bb38d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/servant-0.11
library-dirs: /usr/lib/ghc-8.0.2/site-local/servant-0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/servant-0.11
hs-libraries: HSservant-0.11-2Bfoi0pupMeH5XDpNx7DXi
depends:
    aeson-1.1.2.0-H9d5B7Pgw9tIbOpl8Ot3sY
    attoparsec-0.13.1.0-ETec0FJZJHgARrgZXhaej9 base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22 bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw
    http-api-data-0.3.7.1-HRD4hKOGpF6AwFTT6rOMFv
    http-media-0.7.0-5uqhZ3mCm1731B0EPTVHeA
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    mmorph-1.1.0-BKb9vDVN1ubG7npUIlJCzH
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    natural-transformation-0.4-1wekIVD0YQa62debXjfFg3
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    string-conversions-0.4.0.1-743WgfuBUTV5Nolj1lMwBa
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    vault-0.3.0.7-E4lXhyEMoKrEIYQFhBY3rZ
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-0.11-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant
version: 0.11
id: servant-0.11-El9ZNiUW0kX3q13DPeqxkV
key: servant-0.11-El9ZNiUW0kX3q13DPeqxkV
license: BSD3
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>
category: Servant Web
author: Servant Contributors
exposed: True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Header
    Servant.API.HttpVersion Servant.API.Internal.Test.ComprehensiveAPI
    Servant.API.IsSecure Servant.API.QueryParam Servant.API.Raw
    Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.Sub Servant.API.TypeLevel
    Servant.API.Vault Servant.API.Verbs Servant.API.WithNamedContext
    Servant.Utils.Links Servant.Utils.Enter
abi: 639e9ee13592bd54718233fd5e3e64ad
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/servant-0.11
library-dirs: /usr/lib/ghc-8.0.2/site-local/servant-0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/servant-0.11
hs-libraries: HSservant-0.11-El9ZNiUW0kX3q13DPeqxkV
depends:
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22 bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw
    http-api-data-0.3.7.1-3zEe5ySvc6j6xRQh0wfGfT
    http-media-0.7.1-CpUC2f3C6fm1nyvIESvsCy
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    mmorph-1.1.0-BKb9vDVN1ubG7npUIlJCzH
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    natural-transformation-0.4-1wekIVD0YQa62debXjfFg3
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    string-conversions-0.4.0.1-743WgfuBUTV5Nolj1lMwBa
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    vault-0.3.0.7-E4lXhyEMoKrEIYQFhBY3rZ
haddock-interfaces: /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html: /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
